summaryrefslogtreecommitdiffstats
path: root/win
diff options
context:
space:
mode:
authorsr55 <[email protected]>2020-08-22 15:16:26 +0100
committersr55 <[email protected]>2020-08-22 15:16:48 +0100
commita4a53c3baeafd7b43c5cf79c0ced3d52cf648fd2 (patch)
tree3bade58a7af8f380f067701a6192564b6ae23772 /win
parent6ff96bb1554f623e1ae8f7036c61cf682038c936 (diff)
WinGui: Make it clearer that other media players may work for video preview path in preferences. #3069
Diffstat (limited to 'win')
-rw-r--r--win/CS/HandBrakeWPF/Properties/Resources.Designer.cs21
-rw-r--r--win/CS/HandBrakeWPF/Properties/Resources.de.resx7
-rw-r--r--win/CS/HandBrakeWPF/Properties/Resources.es.resx7
-rw-r--r--win/CS/HandBrakeWPF/Properties/Resources.fr.resx7
-rw-r--r--win/CS/HandBrakeWPF/Properties/Resources.ja.resx7
-rw-r--r--win/CS/HandBrakeWPF/Properties/Resources.ko.resx7
-rw-r--r--win/CS/HandBrakeWPF/Properties/Resources.pt-BR.resx7
-rw-r--r--win/CS/HandBrakeWPF/Properties/Resources.resx13
-rw-r--r--win/CS/HandBrakeWPF/Properties/Resources.ru.resx7
-rw-r--r--win/CS/HandBrakeWPF/Properties/Resources.tr.resx7
-rw-r--r--win/CS/HandBrakeWPF/Properties/Resources.zh.resx7
-rw-r--r--win/CS/HandBrakeWPF/Services/UserSettingService.cs2
-rw-r--r--win/CS/HandBrakeWPF/UserSettingConstants.cs2
-rw-r--r--win/CS/HandBrakeWPF/ViewModels/OptionsViewModel.cs4
-rw-r--r--win/CS/HandBrakeWPF/ViewModels/StaticPreviewViewModel.cs34
-rw-r--r--win/CS/HandBrakeWPF/Views/OptionsView.xaml2
16 files changed, 23 insertions, 118 deletions
diff --git a/win/CS/HandBrakeWPF/Properties/Resources.de.resx b/win/CS/HandBrakeWPF/Properties/Resources.de.resx
index b2a8a2383..dde09e8eb 100644
--- a/win/CS/HandBrakeWPF/Properties/Resources.de.resx
+++ b/win/CS/HandBrakeWPF/Properties/Resources.de.resx
@@ -544,10 +544,6 @@ Soll HandBrake wirklich beendet werden?</value>
<data name="StaticPreviewViewModel_ScanFirst" xml:space="preserve">
<value>Bevor eine Vorschau erstellt werden kann, muss die Quelle überprüft und eine Encodierung festgelegt werden.</value>
</data>
- <data name="StaticPreviewViewModel_UnableToFindVLC" xml:space="preserve">
- <value>VLC-Player nicht gefunden.
-Bitte sicherstellen, dass VLC installiert und der Pfad in den HandBrake-Einstellungen korrekt ist (siehe „Extras &gt; Einstellungen &gt; Allgemein“)</value>
- </data>
<data name="StaticPreviewViewModel_UnableToPlayFile" xml:space="preserve">
<value>Vorschaudatei konnte nicht gefunden werden. Entweder wurde die Datei gelöscht oder die Encodierung ist fehlgeschlagen. Bitte das Aktivitätsprotokoll für Details prüfen.</value>
</data>
@@ -1252,9 +1248,6 @@ Soll sie überschrieben werden?</value>
<data name="Options_Path" xml:space="preserve">
<value>Pfad:</value>
</data>
- <data name="Options_PathToVLC" xml:space="preserve">
- <value>Pfad zum VLC-Player</value>
- </data>
<data name="Options_PreventSleep" xml:space="preserve">
<value>Das System daran hindern während der Encodierung in den Ruhezustand zu fahren</value>
</data>
diff --git a/win/CS/HandBrakeWPF/Properties/Resources.es.resx b/win/CS/HandBrakeWPF/Properties/Resources.es.resx
index 2a2841184..f042e012e 100644
--- a/win/CS/HandBrakeWPF/Properties/Resources.es.resx
+++ b/win/CS/HandBrakeWPF/Properties/Resources.es.resx
@@ -539,10 +539,6 @@ Puede encontrar más información en el registro de actividad.</value>
<data name="StaticPreviewViewModel_ScanFirst" xml:space="preserve">
<value>Primero debe escanear un origen y configurar su codificación antes de crear una vista previa.</value>
</data>
- <data name="StaticPreviewViewModel_UnableToFindVLC" xml:space="preserve">
- <value>No se puede detectar el reproductor VLC.
- Asegúrese de que VLC está instalado y el directorio especificado en las opciones de HandBrake es correcto. (Véase: "Menú Herramientas &gt; Preferencias &gt; General")</value>
- </data>
<data name="StaticPreviewViewModel_UnableToPlayFile" xml:space="preserve">
<value>No se puede encontrar el archivo de vista previa. Se eliminó el archivo o se produjo un error en la codificación. Compruebe el registro de actividad para obtener más información.</value>
</data>
@@ -1247,9 +1243,6 @@ Puede configurar el nivel en el que aparece esta alerta en las preferencias.
<data name="Options_Path" xml:space="preserve">
<value>Directorio:</value>
</data>
- <data name="Options_PathToVLC" xml:space="preserve">
- <value>Directorio a VLC</value>
- </data>
<data name="Options_PreventSleep" xml:space="preserve">
<value>Evitar que el sistema hiberne mientras se codifica</value>
</data>
diff --git a/win/CS/HandBrakeWPF/Properties/Resources.fr.resx b/win/CS/HandBrakeWPF/Properties/Resources.fr.resx
index 63e26d220..5531d808b 100644
--- a/win/CS/HandBrakeWPF/Properties/Resources.fr.resx
+++ b/win/CS/HandBrakeWPF/Properties/Resources.fr.resx
@@ -541,10 +541,6 @@ Veuillez consulter le site Web pour les notes de version.</value>
<data name="StaticPreviewViewModel_ScanFirst" xml:space="preserve">
<value>Vous devez d'abord analyser une source et configurer votre encodage avant de créer un aperçu.</value>
</data>
- <data name="StaticPreviewViewModel_UnableToFindVLC" xml:space="preserve">
- <value>Impossible de détecter le lecteur VLC.
-Assurez-vous que VLC est installé et que le répertoire spécifié dans les options d'HandBrake est correct. (Voir menu "Outils &gt; Préférences &gt; Général")</value>
- </data>
<data name="StaticPreviewViewModel_UnableToPlayFile" xml:space="preserve">
<value>Impossible de trouver le fichier de prévisualisation. Le fichier a été supprimé ou l'encodage a échoué. Consultez le journal d'activité pour plus de détails.</value>
</data>
@@ -1250,9 +1246,6 @@ Souhaitez-vous l'écraser ?</value>
<data name="Options_Path" xml:space="preserve">
<value>Chemin d'accès :</value>
</data>
- <data name="Options_PathToVLC" xml:space="preserve">
- <value>Chemin vers le lecteur VLC</value>
- </data>
<data name="Options_PreventSleep" xml:space="preserve">
<value>Empêcher le système de se mettre en veille pendant l'encodage</value>
</data>
diff --git a/win/CS/HandBrakeWPF/Properties/Resources.ja.resx b/win/CS/HandBrakeWPF/Properties/Resources.ja.resx
index 6551e2fb6..d71570898 100644
--- a/win/CS/HandBrakeWPF/Properties/Resources.ja.resx
+++ b/win/CS/HandBrakeWPF/Properties/Resources.ja.resx
@@ -539,10 +539,6 @@ Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 021
<data name="StaticPreviewViewModel_ScanFirst" xml:space="preserve">
<value>プレビューの前にまずソースをスキャンしてエンコードを設定しなければいけません。</value>
</data>
- <data name="StaticPreviewViewModel_UnableToFindVLC" xml:space="preserve">
- <value>VLCプレーヤーを検出できません。
-VLCがインストールされ、HandBrakeの設定で指定されたディレクトリが正しいことを確認してください。(参照:「[ツール] メニュー/[基本設定]/[一般]」)</value>
- </data>
<data name="StaticPreviewViewModel_UnableToPlayFile" xml:space="preserve">
<value>プレビューファイルが見つかりません。ファイルが削除されたか、エンコードに失敗しました。詳細については、履歴ウィンドウを確認してください。</value>
</data>
@@ -1248,9 +1244,6 @@ VLCがインストールされ、HandBrakeの設定で指定されたディレ�
<data name="Options_Path" xml:space="preserve">
<value>パス:</value>
</data>
- <data name="Options_PathToVLC" xml:space="preserve">
- <value>VLC Playerへのパス</value>
- </data>
<data name="Options_PreventSleep" xml:space="preserve">
<value>エンコード中にシステムがスリープ状態にならないようにする</value>
</data>
diff --git a/win/CS/HandBrakeWPF/Properties/Resources.ko.resx b/win/CS/HandBrakeWPF/Properties/Resources.ko.resx
index 76b7f9686..56a532eea 100644
--- a/win/CS/HandBrakeWPF/Properties/Resources.ko.resx
+++ b/win/CS/HandBrakeWPF/Properties/Resources.ko.resx
@@ -540,10 +540,6 @@ HandBrake를 종료하시겠습니까?</value>
<data name="StaticPreviewViewModel_ScanFirst" xml:space="preserve">
<value>미리보기를 만들기 전에 먼저 파일을 스캔하고 인코딩을 설정하십시오.</value>
</data>
- <data name="StaticPreviewViewModel_UnableToFindVLC" xml:space="preserve">
- <value>VLC 플레이어를 발견할 수 없습니다.
-VLC가 설치되었는지 확인하고 HandBrake의 옵션에 지정된 폴더가 올바른 지 확인하십시오. (보기: "도구 메뉴 &gt; 설정 &gt; 일반")</value>
- </data>
<data name="StaticPreviewViewModel_UnableToPlayFile" xml:space="preserve">
<value>미리보기 파일을 찾을 수 없습니다. 파일이 삭제되었거나 인코딩에 실패하였습니다. 자세한 내용은 액티비티 로그를 확인하십시오.</value>
</data>
@@ -1249,9 +1245,6 @@ VLC가 설치되었는지 확인하고 HandBrake의 옵션에 지정된 폴더�
<data name="Options_Path" xml:space="preserve">
<value>경로: </value>
</data>
- <data name="Options_PathToVLC" xml:space="preserve">
- <value>VLC 플레이어 경로</value>
- </data>
<data name="Options_PreventSleep" xml:space="preserve">
<value>인코딩 중 시스템 절전 방지</value>
</data>
diff --git a/win/CS/HandBrakeWPF/Properties/Resources.pt-BR.resx b/win/CS/HandBrakeWPF/Properties/Resources.pt-BR.resx
index 3f2b62e1b..2d6e9e7bc 100644
--- a/win/CS/HandBrakeWPF/Properties/Resources.pt-BR.resx
+++ b/win/CS/HandBrakeWPF/Properties/Resources.pt-BR.resx
@@ -542,10 +542,6 @@ Por favor, verifique as Notas de Versão no site.</value>
<data name="StaticPreviewViewModel_ScanFirst" xml:space="preserve">
<value>Você deve primeiro analisar uma origem e configurar a codificação antes de pré-visualizar.</value>
</data>
- <data name="StaticPreviewViewModel_UnableToFindVLC" xml:space="preserve">
- <value>Não foi possível encontrar o VLC Player.
-Por favor, certifique-se de que o VLC está instalado e a pasta definida nas opções do HandBrake está correta. (Veja o menu "Ferramentas &gt; Preferências &gt; Geral")</value>
- </data>
<data name="StaticPreviewViewModel_UnableToPlayFile" xml:space="preserve">
<value>Não foi possível encontrar o arquivo de pré-visualização. O arquivo foi excluído ou a conversão falhou. Verifique os detalhes no Log de Atividades.</value>
</data>
@@ -1250,9 +1246,6 @@ Você gostaria de substituí-lo?</value>
<data name="Options_Path" xml:space="preserve">
<value>Caminho:</value>
</data>
- <data name="Options_PathToVLC" xml:space="preserve">
- <value>Caminho para o VLC Player</value>
- </data>
<data name="Options_PreventSleep" xml:space="preserve">
<value>Evitar que o sistema entre em modo de espera durante a conversão</value>
</data>
diff --git a/win/CS/HandBrakeWPF/Properties/Resources.resx b/win/CS/HandBrakeWPF/Properties/Resources.resx
index 04cfbe621..7f55399d7 100644
--- a/win/CS/HandBrakeWPF/Properties/Resources.resx
+++ b/win/CS/HandBrakeWPF/Properties/Resources.resx
@@ -541,10 +541,6 @@ Are you sure you wish to exit HandBrake?</value>
<data name="StaticPreviewViewModel_ScanFirst" xml:space="preserve">
<value>You must first scan a source and setup your encode before creating a preview.</value>
</data>
- <data name="StaticPreviewViewModel_UnableToFindVLC" xml:space="preserve">
- <value>Unable to detect VLC Player.
-Please make sure VLC is installed and the directory specified in HandBrake's options is correct. (See: "Tools Menu &gt; Preferences &gt; General")</value>
- </data>
<data name="StaticPreviewViewModel_UnableToPlayFile" xml:space="preserve">
<value>Unable to find the preview file. Either the file was deleted or the encode failed. Check the activity log for details.</value>
</data>
@@ -1250,8 +1246,8 @@ Would you like to overwrite it?</value>
<data name="Options_Path" xml:space="preserve">
<value>Path: </value>
</data>
- <data name="Options_PathToVLC" xml:space="preserve">
- <value>Path to VLC Player</value>
+ <data name="Options_PathToMediaPlayer" xml:space="preserve">
+ <value>Path to Media Player</value>
</data>
<data name="Options_PreventSleep" xml:space="preserve">
<value>Prevent the system from sleeping while encoding</value>
@@ -1302,7 +1298,8 @@ Would you like to overwrite it?</value>
<value>Video</value>
</data>
<data name="Options_VideoPreviewPath" xml:space="preserve">
- <value>This path is used for the video preview feature only.</value>
+ <value>This path is used for the video preview feature only.
+VLC and MPC-HC are supported. Other players may also work but are not validated.</value>
</data>
<data name="Options_ViewLogDirectory" xml:space="preserve">
<value>View Log Directory</value>
@@ -1584,7 +1581,7 @@ Would you like to overwrite it?</value>
<value>Select a preview image</value>
</data>
<data name="StaticPreviewView_UseSystemDefault" xml:space="preserve">
- <value>Use system default video player</value>
+ <value>Prefer system default video player</value>
</data>
<data name="SubtitlesView_AddCC" xml:space="preserve">
<value>Add Closed Captions when available</value>
diff --git a/win/CS/HandBrakeWPF/Properties/Resources.ru.resx b/win/CS/HandBrakeWPF/Properties/Resources.ru.resx
index fbca0c400..f6d17a070 100644
--- a/win/CS/HandBrakeWPF/Properties/Resources.ru.resx
+++ b/win/CS/HandBrakeWPF/Properties/Resources.ru.resx
@@ -543,10 +543,6 @@ Foreign Audio Preferred, else First - Если существует дорожк
<data name="StaticPreviewViewModel_ScanFirst" xml:space="preserve">
<value>Вы должны сперва сканировать источник и установить кодирование, прежде чем создавать предпросмотр.</value>
</data>
- <data name="StaticPreviewViewModel_UnableToFindVLC" xml:space="preserve">
- <value>Невозможно обнаружить VLC Player.
-Пожалуйста, убедитесь, что VLC установлен и каталог, указанный в настройках HandBrake, верный. (См.: "Меню инструментов &gt; Настройки &gt; Общее")</value>
- </data>
<data name="StaticPreviewViewModel_UnableToPlayFile" xml:space="preserve">
<value>Невозможно найти файл предпросмотра. Либо файл был удален, либо кодирование не удалось. Проверьте Лог активности для получения детальной информации.</value>
</data>
@@ -1248,9 +1244,6 @@ Foreign Audio Preferred, else First - Если существует дорожк
<data name="Options_Path" xml:space="preserve">
<value>Путь: </value>
</data>
- <data name="Options_PathToVLC" xml:space="preserve">
- <value>Путь до плеера VLC</value>
- </data>
<data name="Options_PreventSleep" xml:space="preserve">
<value>Не давать системе уснуть, если происходит кодирование</value>
</data>
diff --git a/win/CS/HandBrakeWPF/Properties/Resources.tr.resx b/win/CS/HandBrakeWPF/Properties/Resources.tr.resx
index 9f14ec8d2..1d99bec25 100644
--- a/win/CS/HandBrakeWPF/Properties/Resources.tr.resx
+++ b/win/CS/HandBrakeWPF/Properties/Resources.tr.resx
@@ -541,10 +541,6 @@ HandBrake'den çıkmak istediğinize emin misiniz?</value>
<data name="StaticPreviewViewModel_ScanFirst" xml:space="preserve">
<value>Önizleme oluşturmadan önce ilk önce bir kaynağı taramanız ve kodunuzu ayarlamalısınız.</value>
</data>
- <data name="StaticPreviewViewModel_UnableToFindVLC" xml:space="preserve">
- <value>VLC Oynatıcı algılanamadı.
-Lütfen VLC'nin kurulu olduğundan ve HandBrake'nin seçeneklerinde belirtilen dizinin doğru olduğundan emin olun. (Bkz. "Araçlar Menüsü &gt; Tercihler &gt; Genel")</value>
- </data>
<data name="StaticPreviewViewModel_UnableToPlayFile" xml:space="preserve">
<value>Önizleme dosyası bulunamadı. Dosya silindi ya da kodlama başarısız oldu. Ayrıntılar için etkinlik günlüğünü kontrol edin.</value>
</data>
@@ -1250,9 +1246,6 @@ Devam etmek istiyor musunuz? </value>
<data name="Options_Path" xml:space="preserve">
<value>Yol:</value>
</data>
- <data name="Options_PathToVLC" xml:space="preserve">
- <value>VLC Oynatıcının Yolu</value>
- </data>
<data name="Options_PreventSleep" xml:space="preserve">
<value>Kodlama yaparken sistemin uyumasını önleyin</value>
</data>
diff --git a/win/CS/HandBrakeWPF/Properties/Resources.zh.resx b/win/CS/HandBrakeWPF/Properties/Resources.zh.resx
index 4574c16ca..bb7eb2edd 100644
--- a/win/CS/HandBrakeWPF/Properties/Resources.zh.resx
+++ b/win/CS/HandBrakeWPF/Properties/Resources.zh.resx
@@ -536,10 +536,6 @@ Foreign Audio Preferred, else First - 如果存在外语轨道,则会将其烧
<data name="StaticPreviewViewModel_ScanFirst" xml:space="preserve">
<value>在创建预览之前,必须先扫描源并设置编码。</value>
</data>
- <data name="StaticPreviewViewModel_UnableToFindVLC" xml:space="preserve">
- <value>无法检测到 VLC 播放器。
-请确保已安装 VLC 并且 HandBrake 选项中指定的目录是正确的。(请参阅:“工具菜单 &gt; 首选项 &gt; 常规”)</value>
- </data>
<data name="StaticPreviewViewModel_UnableToPlayFile" xml:space="preserve">
<value>无法找到预览文件。文件已删除或编码失败。检查活动日志以获取详细信息。</value>
</data>
@@ -1238,9 +1234,6 @@ Foreign Audio Preferred, else First - 如果存在外语轨道,则会将其烧
<data name="Options_Path" xml:space="preserve">
<value>路径:</value>
</data>
- <data name="Options_PathToVLC" xml:space="preserve">
- <value>VLC Player程序路径</value>
- </data>
<data name="Options_PreventSleep" xml:space="preserve">
<value>在编码时防止系统进入睡眠状态</value>
</data>
diff --git a/win/CS/HandBrakeWPF/Services/UserSettingService.cs b/win/CS/HandBrakeWPF/Services/UserSettingService.cs
index 27c3f0796..59afc88ba 100644
--- a/win/CS/HandBrakeWPF/Services/UserSettingService.cs
+++ b/win/CS/HandBrakeWPF/Services/UserSettingService.cs
@@ -269,7 +269,7 @@ namespace HandBrakeWPF.Services
defaults.Add(UserSettingConstants.ShowStatusInTitleBar, false);
defaults.Add(UserSettingConstants.ShowAddAllToQueue, false);
defaults.Add(UserSettingConstants.ShowAddSelectionToQueue, false);
- defaults.Add(UserSettingConstants.VLCPath, @"C:\Program Files\VideoLAN\vlc\vlc.exe");
+ defaults.Add(UserSettingConstants.MediaPlayerPath, @"C:\Program Files\VideoLAN\vlc\vlc.exe");
// Output Files
defaults.Add(UserSettingConstants.AutoNaming, true);
diff --git a/win/CS/HandBrakeWPF/UserSettingConstants.cs b/win/CS/HandBrakeWPF/UserSettingConstants.cs
index e45eb1929..9d5afd3d9 100644
--- a/win/CS/HandBrakeWPF/UserSettingConstants.cs
+++ b/win/CS/HandBrakeWPF/UserSettingConstants.cs
@@ -26,7 +26,7 @@ namespace HandBrakeWPF
public const string MainWindowMinimize = "MainWindowMinimize";
public const string UpdateStatus = "updateStatus";
public const string UseM4v = "useM4v";
- public const string VLCPath = "VLC_Path";
+ public const string MediaPlayerPath = "VLC_Path";
public const string InstanceId = "InstanceId";
public const string X264Step = "X264Step";
public const string LastPreviewDuration = "LastPreviewDuration";
diff --git a/win/CS/HandBrakeWPF/ViewModels/OptionsViewModel.cs b/win/CS/HandBrakeWPF/ViewModels/OptionsViewModel.cs
index 3ad5cc976..bf71cdf05 100644
--- a/win/CS/HandBrakeWPF/ViewModels/OptionsViewModel.cs
+++ b/win/CS/HandBrakeWPF/ViewModels/OptionsViewModel.cs
@@ -1188,7 +1188,7 @@ namespace HandBrakeWPF.ViewModels
// #############################
// VLC Path
- this.VLCPath = this.userSettingService.GetUserSetting<string>(UserSettingConstants.VLCPath) ?? string.Empty;
+ this.VLCPath = this.userSettingService.GetUserSetting<string>(UserSettingConstants.MediaPlayerPath) ?? string.Empty;
// #############################
// Video
@@ -1343,7 +1343,7 @@ namespace HandBrakeWPF.ViewModels
this.userSettingService.SetUserSetting(UserSettingConstants.MetadataPassthru, this.PassthruMetadata);
/* Previews */
- this.userSettingService.SetUserSetting(UserSettingConstants.VLCPath, this.VLCPath);
+ this.userSettingService.SetUserSetting(UserSettingConstants.MediaPlayerPath, this.VLCPath);
/* Video */
this.userSettingService.SetUserSetting(UserSettingConstants.EnableQuickSyncDecoding, this.EnableQuickSyncDecoding);
diff --git a/win/CS/HandBrakeWPF/ViewModels/StaticPreviewViewModel.cs b/win/CS/HandBrakeWPF/ViewModels/StaticPreviewViewModel.cs
index 1908c964f..761354f34 100644
--- a/win/CS/HandBrakeWPF/ViewModels/StaticPreviewViewModel.cs
+++ b/win/CS/HandBrakeWPF/ViewModels/StaticPreviewViewModel.cs
@@ -576,36 +576,16 @@ namespace HandBrakeWPF.ViewModels
}
else
{
- if (!File.Exists(userSettingService.GetUserSetting<string>(UserSettingConstants.VLCPath)))
+ if (File.Exists(userSettingService.GetUserSetting<string>(UserSettingConstants.MediaPlayerPath)))
{
- // Attempt to find VLC if it doesn't exist in the default set location.
- string vlcPath;
-
- if (IntPtr.Size == 8 || (!string.IsNullOrEmpty(Environment.GetEnvironmentVariable("PROCESSOR_ARCHITEW6432"))))
- vlcPath = Environment.GetEnvironmentVariable("ProgramFiles(x86)");
- else
- vlcPath = Environment.GetEnvironmentVariable("ProgramFiles");
-
- if (!string.IsNullOrEmpty(vlcPath))
- {
- vlcPath = Path.Combine(vlcPath, "VideoLAN\\VLC\\vlc.exe");
- }
-
- if (File.Exists(vlcPath))
- {
- userSettingService.SetUserSetting(UserSettingConstants.VLCPath, vlcPath);
- }
- else
- {
- this.errorService.ShowMessageBox(Resources.StaticPreviewViewModel_UnableToFindVLC,
- Resources.Error, MessageBoxButton.OK, MessageBoxImage.Warning);
- }
+ ProcessStartInfo process = new ProcessStartInfo(userSettingService.GetUserSetting<string>(UserSettingConstants.MediaPlayerPath), args);
+ Process.Start(process);
+ return;
}
-
- if (File.Exists(userSettingService.GetUserSetting<string>(UserSettingConstants.VLCPath)))
+ else
{
- ProcessStartInfo vlc = new ProcessStartInfo(userSettingService.GetUserSetting<string>(UserSettingConstants.VLCPath), args);
- Process.Start(vlc);
+ // Fallback to the System Default
+ Process.Start(args);
}
}
}
diff --git a/win/CS/HandBrakeWPF/Views/OptionsView.xaml b/win/CS/HandBrakeWPF/Views/OptionsView.xaml
index fcb860f44..d787ecfb3 100644
--- a/win/CS/HandBrakeWPF/Views/OptionsView.xaml
+++ b/win/CS/HandBrakeWPF/Views/OptionsView.xaml
@@ -155,7 +155,7 @@
<StackPanel Orientation="Vertical" Margin="0,0,0,10">
- <TextBlock Text="{x:Static Properties:Resources.Options_PathToVLC}" FontSize="14" Margin="0,0,0,10"/>
+ <TextBlock Text="{x:Static Properties:Resources.Options_PathToMediaPlayer}" FontSize="14" Margin="0,0,0,10"/>
<StackPanel Orientation="Vertical" Margin="20,0,0,0">
diff --git a/win/CS/HandBrakeWPF/Properties/Resources.Designer.cs b/win/CS/HandBrakeWPF/Properties/Resources.Designer.cs
index 27ccc158b..798ca1c81 100644
--- a/win/CS/HandBrakeWPF/Properties/Resources.Designer.cs
+++ b/win/CS/HandBrakeWPF/Properties/Resources.Designer.cs
@@ -3159,11 +3159,11 @@ namespace HandBrakeWPF.Properties {
}
/// <summary>
/// Looks up a localized string similar to Path to VLC Player.
/// </summary>
- public static string Options_PathToVLC {
+ public static string Options_PathToMediaPlayer {
get {
- return ResourceManager.GetString("Options_PathToVLC", resourceCulture);
+ return ResourceManager.GetString("Options_PathToMediaPlayer", resourceCulture);
}
}
@@ -3375,7 +3375,8 @@ namespace HandBrakeWPF.Properties {
}
/// <summary>
- /// Looks up a localized string similar to This path is used for the video preview feature only..
+ /// Looks up a localized string similar to This path is used for the video preview feature only.
+ ///VLC and MPC-HC are supported. Other players may also work but are not validated..
/// </summary>
public static string Options_VideoPreviewPath {
get {
@@ -5684,7 +5685,7 @@ namespace HandBrakeWPF.Properties {
}
/// <summary>
- /// Looks up a localized string similar to Use system default video player.
+ /// Looks up a localized string similar to Prefer system default video player.
/// </summary>
public static string StaticPreviewView_UseSystemDefault {
get {
@@ -5720,16 +5721,6 @@ namespace HandBrakeWPF.Properties {
}
/// <summary>
- /// Looks up a localized string similar to Unable to detect VLC Player.
- ///Please make sure VLC is installed and the directory specified in HandBrake&apos;s options is correct. (See: &quot;Tools Menu &gt; Preferences &gt; General&quot;).
- /// </summary>
- public static string StaticPreviewViewModel_UnableToFindVLC {
- get {
- return ResourceManager.GetString("StaticPreviewViewModel_UnableToFindVLC", resourceCulture);
- }
- }
-
- /// <summary>
/// Looks up a localized string similar to Unable to find the preview file. Either the file was deleted or the encode failed. Check the activity log for details..
/// </summary>
public static string StaticPreviewViewModel_UnableToPlayFile {
@@ -3159,11 +3159,11 @@ namespace HandBrakeWPF.Properties {
}
/// <summary>
- /// Looks up a localized string similar to Path to VLC Player.
+ /// Looks up a localized string similar to Path to Media Player.
/// </summary>